@@ -369,10 +369,6 @@ class MCPropagation:
             for i in range(len(x)):
                 if not hasattr(x[i], "__len__"):
                     MC_data[i] = self.generate_samples_systematic(x[i], u_x[i])
-                elif all(
-                    (u_x[i] == 0).flatten()
-                ):  # This is the case if one of the variables has no uncertainty
-                    MC_data[i] = np.tile(x[i].flatten(), (self.MCsteps, 1)).T
                 elif corr_x[i] == "rand":
                     MC_data[i] = self.generate_samples_random(x[i], u_x[i])
                 elif corr_x[i] == "syst":
@@ -583,10 +579,6 @@ class MCPropagation:
             for i in range(len(x)):
                 if not hasattr(x[i], "__len__"):
                     MC_data[i] = self.generate_samples_systematic(x[i], cov_x[i])
-                elif all(
-                    (cov_x[i] == 0).flatten()
-                ):  # This is the case if one of the variables has no uncertainty
-                    MC_data[i] = np.tile(x[i].flatten(), (self.MCsteps, 1)).T
                 elif param_fixed is not None:
                     if param_fixed[i] and (len(x[i].shape) == 2):
                         MC_data[i] = np.array(
